You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lenya.apache.org by an...@apache.org on 2007/04/30 14:53:13 UTC

svn commit: r533732 - in /lenya/trunk: src/impl/java/org/apache/lenya/cms/publication/ src/modules/xopus/ src/pubs/blog/config/ src/pubs/default/config/ src/pubs/default/java/src/org/apache/lenya/defaultpub/cms/publication/templating/ src/targets/ src/...

Author: andreas
Date: Mon Apr 30 05:53:11 2007
New Revision: 533732

URL: http://svn.apache.org/viewvc?view=rev&rev=533732
Log:
Rename publication.xconf to publication.xml. This fixes bug 42233.

Added:
    lenya/trunk/src/pubs/blog/config/publication.xml
      - copied unchanged from r532633, lenya/trunk/src/pubs/blog/config/publication.xconf
    lenya/trunk/src/pubs/default/config/publication.xml
      - copied unchanged from r532633, lenya/trunk/src/pubs/default/config/publication.xconf
Removed:
    lenya/trunk/src/pubs/blog/config/publication.xconf
    lenya/trunk/src/pubs/default/config/publication.xconf
Modified:
    lenya/trunk/src/impl/java/org/apache/lenya/cms/publication/PublicationConfiguration.java
    lenya/trunk/src/modules/xopus/sitemap.xmap
    lenya/trunk/src/pubs/default/java/src/org/apache/lenya/defaultpub/cms/publication/templating/Instantiator.java
    lenya/trunk/src/targets/dist-build.xml
    lenya/trunk/src/targets/migration-build.xml
    lenya/trunk/src/targets/properties-build.xml
    lenya/trunk/src/targets/test-build.xml
    lenya/trunk/src/targets/webapp-build.xml
    lenya/trunk/src/webapp/global-sitemap.xmap
    lenya/trunk/src/webapp/lenya/i18n.xmap
    lenya/trunk/src/webapp/lenya/resources/i18n/modules2xinclude.xsl
    lenya/trunk/src/webapp/lenya/resources/schemas/publication.rng
    lenya/trunk/src/webapp/lenya/xslt/util/aggregate-publications.xsl
    lenya/trunk/src/webapp/readme.xml
    lenya/trunk/tools/anttasks/build/classes/org/apache/lenya/cms/ant/CopyJavaSourcesTask.class
    lenya/trunk/tools/anttasks/build/classes/org/apache/lenya/cms/ant/CopyPublicationsTask.class
    lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyJavaSourcesTask.java
    lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyPublicationsTask.java
    lenya/trunk/tools/configure/src/java/org/apache/lenya/config/impl/ConfigureCommandLine.java

Modified: lenya/trunk/src/impl/java/org/apache/lenya/cms/publication/PublicationConfiguration.java
URL: http://svn.apache.org/viewvc/lenya/trunk/src/impl/java/org/apache/lenya/cms/publication/PublicationConfiguration.java?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/modules/xopus/sitemap.xmap (original)
+++ lenya/trunk/src/modules/xopus/sitemap.xmap Mon Apr 30 05:53:11 2007
@@ -57,7 +57,7 @@
         <!-- **                                                          ** -->
         <!-- ** NOTE: page-envelope:document-path depends on the         ** -->
         <!-- **       publication specific DocumentIdToPathMapper which  ** -->
-        <!-- **       is configured within config/publication.xconf      ** -->
+        <!-- **       is configured within config/publication.xml        ** -->
         <!-- ************************************************************** -->
         
           <map:match pattern="open" type="step">

Modified: lenya/trunk/src/pubs/default/java/src/org/apache/lenya/defaultpub/cms/publication/templating/Instantiator.java
URL: http://svn.apache.org/viewvc/lenya/trunk/src/pubs/default/java/src/org/apache/lenya/defaultpub/cms/publication/templating/Instantiator.java?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/pubs/default/java/src/org/apache/lenya/defaultpub/cms/publication/templating/Instantiator.java (original)
+++ lenya/trunk/src/pubs/default/java/src/org/apache/lenya/defaultpub/cms/publication/templating/Instantiator.java Mon Apr 30 05:53:11 2007
@@ -60,7 +60,7 @@
         org.apache.lenya.cms.publication.templating.Instantiator, Serviceable {
 
     protected static final String[] sourcesToCopy = { 
-            "config/publication.xconf",
+            "config/publication.xml",
             "config/access-control/access-control.xml", "config/access-control/policies/", 
             "config/access-control/usecase-policies.xml", 
             "config/workflow/workflow.xml",
@@ -70,7 +70,7 @@
     // the correct solution suggested by andreas is not to meddle with config files here at all, but instead implement
     // appropriate setter functions in the Publication class. postponed to after 1.4.
     // thus, don't waste too much effort on this file, it's all an intermediate hack.
-    private static final String CONFIGURATION_FILE = "config/publication.xconf";
+    private static final String CONFIGURATION_FILE = "config/publication.xml";
     private static final String CONFIGURATION_NAMESPACE = "http://apache.org/cocoon/lenya/publication/1.1";
     private static final String ELEMENT_NAME = "name";
     private static final String ELEMENT_TEMPLATE = "template";

Modified: lenya/trunk/src/targets/dist-build.xml
URL: http://svn.apache.org/viewvc/lenya/trunk/src/targets/dist-build.xml?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/targets/dist-build.xml (original)
+++ lenya/trunk/src/targets/dist-build.xml Mon Apr 30 05:53:11 2007
@@ -119,7 +119,7 @@
   	<replace dir="${dist.src.dir}">
           <include name="**/welcome.xml"/>
   	  <include name="**/about.xml"/>
-	  <include name="**/config/publication.xconf"/>
+	  <include name="**/config/publication.xml"/>
   	  <replacefilter token="@lenya.version@" value="${version}"/>
   	  <replacefilter token="@lenya.revision@" value="${lenya.revision}"/>
   	</replace>

Modified: lenya/trunk/src/targets/migration-build.xml
URL: http://svn.apache.org/viewvc/lenya/trunk/src/targets/migration-build.xml?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/targets/migration-build.xml (original)
+++ lenya/trunk/src/targets/migration-build.xml Mon Apr 30 05:53:11 2007
@@ -28,7 +28,7 @@
     
     <echo>
     CAUTION: This target does not work out of the box if you use an external content directory
-    in publication.xconf. Please change the parameters of the target accordingly.
+    in publication.xml. Please change the parameters of the target accordingly.
     </echo>
     
     <property name="publication" value=""/>

Modified: lenya/trunk/src/targets/properties-build.xml
URL: http://svn.apache.org/viewvc/lenya/trunk/src/targets/properties-build.xml?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/targets/properties-build.xml (original)
+++ lenya/trunk/src/targets/properties-build.xml Mon Apr 30 05:53:11 2007
@@ -64,6 +64,12 @@
     </not>
   </condition>
   <fail unless="target.vm">Please use a JVM 1.4 or superior to compile lenya ${version}</fail>
+  
+  <!--
+  The minimal supported Java version. The class files we ship with Lenya (e.g., build tasks)
+  are compiled for this version.
+  -->
+  <property name="target.vm.minimal" value="1.4"/>
 
   <property name="packages"      value="*.*"/>
 
@@ -163,15 +169,14 @@
 
   <!-- Compile tasks -->
   <target name="compile-build-tasks" description="Target to compile tasks needed during build">
-
     <javac srcdir="tools/anttasks/src"
            destdir="tools/anttasks/build/classes"
            debug="${debug}"
            optimize="{optimize}"
            deprecation="${deprecation}"
-           target="${target.vm}"
+           target="${target.vm.minimal}"
            nowarn="${nowarn}"
-           source="${target.vm}"/>
+           source="${target.vm.minimal}"/>
 	   <!--
            classpathref="classpath"
 	   -->

Modified: lenya/trunk/src/targets/test-build.xml
URL: http://svn.apache.org/viewvc/lenya/trunk/src/targets/test-build.xml?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/targets/test-build.xml (original)
+++ lenya/trunk/src/targets/test-build.xml Mon Apr 30 05:53:11 2007
@@ -73,7 +73,7 @@
       </fileset>
     </copy>
     <replace encoding="utf-8"
-      file="${build.webapp}/lenya/pubs/${test.pub.id}/config/publication.xconf"
+      file="${build.webapp}/lenya/pubs/${test.pub.id}/config/publication.xml"
       token="Default Publication" value="Test Publication"/>
   </target>
   

Modified: lenya/trunk/src/targets/webapp-build.xml
URL: http://svn.apache.org/viewvc/lenya/trunk/src/targets/webapp-build.xml?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/targets/webapp-build.xml (original)
+++ lenya/trunk/src/targets/webapp-build.xml Mon Apr 30 05:53:11 2007
@@ -70,7 +70,7 @@
     <!-- Copy publications -->
     <copyPubs todir="${build.webapp}/lenya/pubs"
       pubsrootdirs="${pubs.root.dirs}"
-      excludes="CVS,.svn,cocoon-xconf,lenya-roles,local.publication.xconf,local.ac.xconf,.project"/>
+      excludes="CVS,.svn,cocoon-xconf,lenya-roles,local.publication.xml,local.ac.xconf,.project"/>
     
     <bulkCopy 
       sourcedirs="${pubs.root.dirs}" 
@@ -196,7 +196,7 @@
     <replace dir="${build.webapp}">
       <include name="lenya/content/welcome.xml"/>
       <include name="lenya/content/about.xml"/>
-      <include name="**/config/publication.xconf"/>
+      <include name="**/config/publication.xml"/>
       <replacefilter token="@lenya.version@" value="${version}"/>
       <replacefilter token="@lenya.revision@" value="${lenya.revision}"/>
     </replace>

Modified: lenya/trunk/src/webapp/global-sitemap.xmap
URL: http://svn.apache.org/viewvc/lenya/trunk/src/webapp/global-sitemap.xmap?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/webapp/global-sitemap.xmap (original)
+++ lenya/trunk/src/webapp/global-sitemap.xmap Mon Apr 30 05:53:11 2007
@@ -217,7 +217,7 @@
       <!-- menu-xml/modules -->
       <!-- menu-xml/modules/{pub-id}/{area}.xml -->
       <map:match pattern="menu-xml/modules/*/*.xml">
-        <map:generate src="aggregate-fallback://config/publication.xconf"/>
+        <map:generate src="aggregate-fallback://config/publication.xml"/>
         <map:transform src="lenya/xslt/modules/modules2xinclude.xsl">
           <map:parameter name="area" value="{2}"/>
         </map:transform>
@@ -373,7 +373,7 @@
       <map:match pattern="*/introduction.html">
         <map:aggregate element="aggregation-wrapper">
           <map:part src="aggregate-fallback://readme.xml"/>
-          <map:part src="lenya/pubs/{1}/config/publication.xconf"/>
+          <map:part src="lenya/pubs/{1}/config/publication.xml"/>
         </map:aggregate>
         <map:transform src="lenya/xslt/util/introduction.xsl"/>
         <map:call resource="style-cms-page"/>

Modified: lenya/trunk/src/webapp/lenya/i18n.xmap
URL: http://svn.apache.org/viewvc/lenya/trunk/src/webapp/lenya/i18n.xmap?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/webapp/lenya/i18n.xmap (original)
+++ lenya/trunk/src/webapp/lenya/i18n.xmap Mon Apr 30 05:53:11 2007
@@ -29,7 +29,7 @@
   <map:resources>
     <map:resource name="serializeCatalogue">
       <map:select type="resource-exists">
-        <map:when test="context://lenya/pubs/{page-envelope:publication-id}/config/publication.xconf">
+        <map:when test="context://lenya/pubs/{page-envelope:publication-id}/config/publication.xml">
           <map:transform src="resources/i18n/modules2xinclude.xsl">
             <map:parameter name="pubId" value="{page-envelope:publication-id}"/>
             <map:parameter name="catalogue" value="{catalogue}"/>

Modified: lenya/trunk/src/webapp/lenya/resources/i18n/modules2xinclude.xsl
URL: http://svn.apache.org/viewvc/lenya/trunk/src/webapp/lenya/resources/i18n/modules2xinclude.xsl?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/webapp/lenya/resources/i18n/modules2xinclude.xsl (original)
+++ lenya/trunk/src/webapp/lenya/resources/i18n/modules2xinclude.xsl Mon Apr 30 05:53:11 2007
@@ -31,7 +31,7 @@
   <xsl:template match="catalogue">
     <xsl:copy>
       <xsl:copy-of select="@*|node()"/>
-      <xsl:apply-templates select="document('aggregate-fallback://config/publication.xconf')/*/lenya:modules/lenya:module"/>
+      <xsl:apply-templates select="document('aggregate-fallback://config/publication.xml')/*/lenya:modules/lenya:module"/>
     </xsl:copy>
   </xsl:template>
 

Modified: lenya/trunk/src/webapp/lenya/resources/schemas/publication.rng
URL: http://svn.apache.org/viewvc/lenya/trunk/src/webapp/lenya/resources/schemas/publication.rng?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/webapp/lenya/resources/schemas/publication.rng (original)
+++ lenya/trunk/src/webapp/lenya/resources/schemas/publication.rng Mon Apr 30 05:53:11 2007
@@ -18,12 +18,12 @@
 
 <!-- 
   This RELAX NG grammar defines the configuration file of a. Lenya publication.
-  Configuration files must be located under "$YOURPUBROOT/$PUBNAME/config/publication.xconf".
+  Configuration files must be located under "$YOURPUBROOT/$PUBNAME/config/publication.xml".
   
   This schema is new as of 2007-02-23. It is NOT backwards-compatible. It combines the
-  contents of $YOURPUBROOT/$PUBNAME/publication.xml and $YOURPUBROOT/$PUBNAME/config/publication.xconf.
+  contents of $YOURPUBROOT/$PUBNAME/publication.xml and $YOURPUBROOT/$PUBNAME/config/publication.xml.
   
-  The publication.xconf file is parsed by:
+  The publication.xml file is parsed by:
   
   * src/impl/java/org/apache/lenya/cms/publication/PublicationConfiguration.java
   * src/java/org/apache/lenya/cms/publication/templating/ExistingUsecaseResolver.java

Modified: lenya/trunk/src/webapp/lenya/xslt/util/aggregate-publications.xsl
URL: http://svn.apache.org/viewvc/lenya/trunk/src/webapp/lenya/xslt/util/aggregate-publications.xsl?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/webapp/lenya/xslt/util/aggregate-publications.xsl (original)
+++ lenya/trunk/src/webapp/lenya/xslt/util/aggregate-publications.xsl Mon Apr 30 05:53:11 2007
@@ -34,7 +34,7 @@
     <xsl:for-each select="dir:directory">
       <lenya:publication dirname="{@name}">
         <xi:include 
-          href="lenya/pubs/{@name}/config/publication.xconf"
+          href="lenya/pubs/{@name}/config/publication.xml"
           xpointer="xpointer(/*/*)"
         >
           <xi:fallback>

Modified: lenya/trunk/src/webapp/readme.xml
URL: http://svn.apache.org/viewvc/lenya/trunk/src/webapp/readme.xml?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/src/webapp/readme.xml (original)
+++ lenya/trunk/src/webapp/readme.xml Mon Apr 30 05:53:11 2007
@@ -35,6 +35,15 @@
     
     <h2>Important notes for beta testers of Lenya 1.4-RC</h2>
     
+    <h3>2007-04-26: Renamed
+      <code>$PUB_HOME/config/publication.xconf</code> to <code>publication.xml</code></h3>
+    
+    <p>
+      Please rename your <code>$PUB_HOME/config/publication.xconf</code> file to
+      <code>$PUB_HOME/config/publication.xml</code>.
+      This change was done to preserve consistency with the other configuration file names.
+    </p>
+    
     <h3>2007-04-23: Moved and renamed
     <code>$PUB_HOME/config/lucene_index.xconf</code></h3>
     
@@ -100,7 +109,7 @@
     <p>
       If you want to provide a custom README for your publication (maybe you
       have used the old &lt;lenya:readme/&gt; in the now gone
-      publication.xml), you can put it in <code>$YOURPUB/readme.xml</code>. 
+      publication.xconf), you can put it in <code>$YOURPUB/readme.xml</code>. 
       It is now a standard Lenya CMS page in the
       <code>http://apache.org/cocoon/lenya/cms-page/1.0</code> namespace.
     </p>  

Modified: lenya/trunk/tools/anttasks/build/classes/org/apache/lenya/cms/ant/CopyJavaSourcesTask.class
URL: http://svn.apache.org/viewvc/lenya/trunk/tools/anttasks/build/classes/org/apache/lenya/cms/ant/CopyJavaSourcesTask.class?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
Binary files - no diff available.

Modified: lenya/trunk/tools/anttasks/build/classes/org/apache/lenya/cms/ant/CopyPublicationsTask.class
URL: http://svn.apache.org/viewvc/lenya/trunk/tools/anttasks/build/classes/org/apache/lenya/cms/ant/CopyPublicationsTask.class?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
Binary files - no diff available.

Modified: lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyJavaSourcesTask.java
URL: http://svn.apache.org/viewvc/lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyJavaSourcesTask.java?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyJavaSourcesTask.java (original)
+++ lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyJavaSourcesTask.java Mon Apr 30 05:53:11 2007
@@ -71,7 +71,7 @@
 
             if (path.isDirectory()) {
                 // In the case of a publication
-                if (new File(path, "/config/publication.xconf").isFile()) {
+                if (new File(path, "/config/publication.xml").isFile()) {
                     copyContentOfDir(new File(path, this.javaDir),
                             absoluteBuildDir,
                             twoTuple,

Modified: lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyPublicationsTask.java
URL: http://svn.apache.org/viewvc/lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyPublicationsTask.java?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyPublicationsTask.java (original)
+++ lenya/trunk/tools/anttasks/src/org/apache/lenya/cms/ant/CopyPublicationsTask.java Mon Apr 30 05:53:11 2007
@@ -67,20 +67,20 @@
      */
     public void copy(String pubsRootDir, FilenameFilter filter, TwoTuple twoTuple) {
             // In the case the pubsRootDir is publication dir
-            if (new File(pubsRootDir, "/config/publication.xconf").isFile()) {
+            if (new File(pubsRootDir, "/config/publication.xml").isFile()) {
                 File pubDir = new File(pubsRootDir);
                 log("Copy publication: " + pubDir);
                 CopyJavaSourcesTask.copyDir(pubDir, new File(this.toDir.toString()), twoTuple, filter, this);
-                File localPublicationXConf = new File(pubDir, "/config/local.publication.xconf");
+                File localPublicationXConf = new File(pubDir, "/config/local.publication.xml");
                 if (localPublicationXConf.isFile()) {
-                    File publicationXConf = new File(this.toDir.toString() + "/" + pubDir.getName() + "/config/publication.xconf");
+                    File publicationXConf = new File(this.toDir.toString() + "/" + pubDir.getName() + "/config/publication.xml");
                     log("Patch config file with local version: " + localPublicationXConf + " " + publicationXConf);
                     CopyJavaSourcesTask.copyFile(localPublicationXConf, publicationXConf, twoTuple, this, true);
                 }
 
-                File localAccessControlXConf = new File(pubDir, "/config/ac/local.ac.xconf");
+                File localAccessControlXConf = new File(pubDir, "/config/access-control/local.access-control.xml");
                 if (localAccessControlXConf.isFile()) {
-                    File accessControlXConf = new File(this.toDir.toString() + "/" + pubDir.getName() + "/config/ac/ac.xconf");
+                    File accessControlXConf = new File(this.toDir.toString() + "/" + pubDir.getName() + "/config/access-control/access-control.xml");
                     log("Patch access control config file with local version: " + localAccessControlXConf + " " + accessControlXConf);
                     CopyJavaSourcesTask.copyFile(localAccessControlXConf, accessControlXConf, twoTuple, this, true);
                 }

Modified: lenya/trunk/tools/configure/src/java/org/apache/lenya/config/impl/ConfigureCommandLine.java
URL: http://svn.apache.org/viewvc/lenya/trunk/tools/configure/src/java/org/apache/lenya/config/impl/ConfigureCommandLine.java?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================
--- lenya/trunk/tools/configure/src/java/org/apache/lenya/config/impl/ConfigureCommandLine.java (original)
+++ lenya/trunk/tools/configure/src/java/org/apache/lenya/config/impl/ConfigureCommandLine.java Mon Apr 30 05:53:11 2007
@@ -59,8 +59,8 @@
 
         /*
         FileConfiguration defaultPub = new PublicationConfiguration();
-        defaultPub.setFilenameDefault(rootDir + "src/pubs/default/config/publication.xconf");
-        defaultPub.setFilenameLocal(rootDir + "src/pubs/default/config/local.publication.xconf");
+        defaultPub.setFilenameDefault(rootDir + "src/pubs/default/config/publication.xml");
+        defaultPub.setFilenameLocal(rootDir + "src/pubs/default/config/local.publication.xml");
         */
 
         /*



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@lenya.apache.org
For additional commands, e-mail: commits-help@lenya.apache.org
--- lenya/trunk/src/impl/java/org/apache/lenya/cms/publication/PublicationConfiguration.java (original)
+++ lenya/trunk/src/impl/java/org/apache/lenya/cms/publication/PublicationConfiguration.java Mon Apr 30 05:53:11 2007
@@ -32,7 +32,7 @@
 /**
  * A publication's configuration.
  * Keep in sync with src/webapp/lenya/resources/schemas/publication.rng!
  * FIXME: validate publication.xconf before attempting to parse
  */
 public class PublicationConfiguration extends AbstractLogEnabled implements Publication {
 
@@ -52,7 +52,7 @@
      * <code>CONFIGURATION_FILE</code> The publication configuration file
      */
     public static final String CONFIGURATION_FILE = CONFIGURATION_PATH + File.separator
-            + "publication.xconf";
+            + "publication.xml";
 
     private static final String CONFIGURATION_NAMESPACE = 
             "http://apache.org/cocoon/lenya/publication/1.1" ;
@@ -146,7 +146,7 @@
                 if (config.getChild(ELEMENT_PATH_MAPPER).getNamespace() != CONFIGURATION_NAMESPACE) {
                    getLogger().warn("Deprecated configuration: the publication configuration elements in "
                        + configFile + " must be in the " + CONFIGURATION_NAMESPACE + " namespace."
-                       + " See webapp/lenya/resources/schemas/publication.xconf.");
+                       + " See webapp/lenya/resources/schemas/publication.xml.");
                 }
                 pathMapperClassName = config.getChild(ELEMENT_PATH_MAPPER).getValue();
                 Class pathMapperClass = Class.forName(pathMapperClassName);
@@ -254,7 +254,7 @@
     }
 
     /**
-     * @return The configuration file (publication.xconf).
+     * @return The configuration file ({@link #CONFIGURATION_FILE}).
      */
     protected File getConfigurationFile() {
         File configFile = new File(getDirectory(), CONFIGURATION_FILE);
@@ -32,7 +32,7 @@
  * A publication's configuration.
  * Keep in sync with src/webapp/lenya/resources/schemas/publication.rng!
- * FIXME: validate publication.xconf before attempting to parse
+ * FIXME: validate publication.xml before attempting to parse
  */
 public class PublicationConfiguration extends AbstractLogEnabled implements Publication {

Modified: lenya/trunk/src/modules/xopus/sitemap.xmap
URL: http://svn.apache.org/viewvc/lenya/trunk/src/modules/xopus/sitemap.xmap?view=diff&rev=533732&r1=533731&r2=533732
==============================================================================